@@ -42,7 +42,7 @@ local function _headers(ctx)
     end
     local headers = ctx.headers
     if not headers then
-        headers = get_headers()
+        headers = get_headers(0)
         ctx.headers = headers
     end
 
@@ -179,8 +179,6 @@ end
 
 
 function _M.get_body(max_size, ctx)
-    -- TODO: improve the check with set client_max_body dynamically
-    -- which requires to change Nginx source code
     if max_size then
         local var = ctx and ctx.var or ngx.var
         local content_length = tonumber(var.http_content_length)
@@ -258,6 +256,7 @@ function _M.get_port(ctx)
     return tonumber(ctx.var.server_port)
 end
 
+_M.get_method = ngx.req.get_method
 
 function _M.get_http_version()
     return ngx.req.http_version()
